# This file is part of source_injection.
#
# Developed for the LSST Data Management System.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

"""
The source_injection package provides functionality for injecting synthetic
sources into astronomical images.

Modules
-------
inject_base : Base classes for injection tasks.
inject_exposure : Classes for injecting sources into individual exposures.
inject_visit : Classes for injecting sources into individual visit images.
inject_coadd : Classes for injecting sources into coadd images.
inject_engine : Functions that assist in the manipulation of GalSim objects.
utils : Utility functions for injection tasks.
"""

from .inject_base import *  # noqa: F401,F403
from .inject_coadd import *  # noqa: F401,F403
from .inject_engine import *  # noqa: F401,F403
from .inject_exposure import *  # noqa: F401,F403
from .inject_visit import *  # noqa: F401,F403
from .utils import *  # noqa: F401,F403
from .version import *  # noqa: F401,F403. Generated by sconsUtils.
